//Do Not Localize
//
// Expected format is for a div to contain up to three things:
// 1) a link to the chapter
// 2) an optional disclosure triangle with 'open' and 'closed'
//	attributes indicating what open/closed image to use.
// 3) an optional span next to the chapter link that can be collapsed
//	and expanded.
//
// <div>
//	  <formatting_stuff><a href="bogus">Bundles</a></formatting_stuff>
//	  <span>...collapsible section...</span>
// </div>

function load_toc_page()
{
	// Set action for all links, expand first chapter and collapse the rest.
	for(var i = 0; i < document.links.length; i++) 
	{
		document.links[i].onmousedown = link_action;
	}
	
	var divs = document.getElementsByTagName("DIV");
	for (var i = 0; i < divs.length; i++)
	{
		if( divs[i].getAttribute('expanded') == "false" )
		{
			collapse(divs[i]);
		}
		else
		{
			expand(divs[i]);
		}
	}
	
}

function disclosure_triangle()
{
	var parent = div_parent(this);
	if (parent)
	{
		toggle(parent);
	}
	return 0;
}

// Private

function link_action()
{
	// Called by a link when clicked.
	// If this is a regular link, open the section if it's closed.
	// If it contains a disclosure triangle, toggle the section.
	
	var div = div_parent(this);
	
	if (div && div.className)
	{
		
		var triangle = disclosure_image(this);
		if (triangle)
		{
			toggle(div);
		}
		else if(div.className == "jtoc_closed")
		{
			expand(div);
		}  
	}
}

function toggle(div)
{
	// Toggle the div's disclosure status.
	if (div.className)
	{
		if (div.className == "jtoc_open")
		{
			collapse(div);
		}
		else if (div.className == "jtoc_closed")
		{
			expand(div);
		}
	}
}

function expand(div)
{
	if (isNetscape())
	{
		// Netscape can't deal with setting display to none after initial page load,
		// so skip expanding/collapsing.
		return;
	}
	
	if (div.className != "jtoc_open")
	{
		div.className = "jtoc_open";
		
		var child = collapsible_child(div);
		if (child) { child.style.display = ""; }
		
		var image = disclosure_image(div);
		if (image) { image.src = image.getAttribute("open"); }
	}
}

function collapse(div)
{
	if (isNetscape())
	{
		// Netscape can't deal with setting display to none after initial page load,
		// so skip expanding/collapsing.
		return;
	}

	if (div.className != "jtoc_closed")
	{
		div.className = "jtoc_closed";
		
		var child = collapsible_child(div);
		if (child) { child.style.display = "none"; }
		
		var image = disclosure_image(div);
		if (image) { image.src = image.getAttribute("closed"); }
	}
}

function disclosure_image(div)
{
	var images = div.getElementsByTagName("IMG");
	if (images.length)
	{
		for (var i = 0; i < images.length; i++)
		{
			var image = images[i];
			var open = image.getAttribute("open")
			if (open)
			{
				return image;
			}
		}
	}
}

function collapsible_child(div)
{
	// Get the first (and should be only) div child.
	var span_nodes = div.getElementsByTagName("SPAN");
	
	if (span_nodes.length)
	{
		return span_nodes[0];
	}
}

function div_parent(element)
{
	// Find the first parent that is a DIV.
	var div_parent = element.parentNode;
	while (div_parent && div_parent.nodeName != "DIV")
	{
		div_parent = div_parent.parentNode;
	}
	
	return div_parent;
}

function isNetscape()
{
	if (navigator.appName == "Netscape")
	{
		var regex = /AppleWebKit/;
		if (!regex.test(navigator.appVersion))
		{
			return 1;
		}
	}
	
	return 0;
}